import { createRoot } from "react-dom/client";
import { StrictMode } from "react";
import SurveyComponent from "./SurveyComponent";

const container = document.getElementById("root");
const root = createRoot(container);
root.render(
  <StrictMode>
    <SurveyComponent />
  </StrictMode>
);
